@@ -52,6 +52,7 @@ RTS_RET(stg_upd_frame);
 RTS_RET(stg_bh_upd_frame);
 RTS_RET(stg_marked_upd_frame);
 RTS_RET(stg_noupd_frame);
+RTS_RET(stg_orig_thunk_info_frame);
 RTS_RET(stg_catch_frame);
 RTS_RET(stg_catch_retry_frame);
 RTS_RET(stg_atomically_frame);
@@ -60,9 +61,15 @@ RTS_RET(stg_catch_stm_frame);
 RTS_RET(stg_unmaskAsyncExceptionszh_ret);
 RTS_RET(stg_maskUninterruptiblezh_ret);
 RTS_RET(stg_maskAsyncExceptionszh_ret);
-RTS_RET(stg_stack_underflow_frame);
+RTS_RET(stg_stack_underflow_frame_d);
+RTS_RET(stg_stack_underflow_frame_v16);
+RTS_RET(stg_stack_underflow_frame_v32);
+RTS_RET(stg_stack_underflow_frame_v64);
 RTS_RET(stg_keepAlive_frame);
-RTS_RET(stg_restore_cccs);
+RTS_RET(stg_restore_cccs_d);
+RTS_RET(stg_restore_cccs_v16);
+RTS_RET(stg_restore_cccs_v32);
+RTS_RET(stg_restore_cccs_v64);
 RTS_RET(stg_restore_cccs_eval);
 RTS_RET(stg_prompt_frame);
 
@@ -82,7 +89,6 @@ RTS_RET(stg_prompt_frame);
 /* Magic glue code for when compiled code returns a value in R1/F1/D1
    or a VoidRep to the interpreter. */
 RTS_RET(stg_ctoi_R1p);
-RTS_RET(stg_ctoi_R1unpt);
 RTS_RET(stg_ctoi_R1n);
 RTS_RET(stg_ctoi_F1);
 RTS_RET(stg_ctoi_D1);
@@ -262,8 +268,8 @@ RTS_ENTRY(stg_NO_FINALIZER);
 extern DLL_IMPORT_RTS StgWordArray stg_CHARLIKE_closure;
 extern DLL_IMPORT_RTS StgWordArray stg_INTLIKE_closure;
 #else
-extern DLL_IMPORT_RTS StgIntCharlikeClosure stg_CHARLIKE_closure[];
-extern DLL_IMPORT_RTS StgIntCharlikeClosure stg_INTLIKE_closure[];
+extern DLL_IMPORT_RTS StgIntCharlikeClosure stg_CHARLIKE_closure[MAX_CHARLIKE - MIN_CHARLIKE + 1];
+extern DLL_IMPORT_RTS StgIntCharlikeClosure stg_INTLIKE_closure[MAX_INTLIKE - MIN_INTLIKE + 1];
 #endif
 
 /* StgStartup */
@@ -365,6 +371,14 @@ RTS_FUN_DECL(stg_ap_pppppp_fast);
 RTS_FUN_DECL(stg_PAP_apply);
 RTS_FUN_DECL(stg_CONTINUATION_apply);
 
+/* Defined in separate AutoApply_{V16,V32,V64}.cmm files and imported into AutoApply.cmm */
+RTS_FUN_DECL(stg_ap_stk_v16);
+RTS_FUN_DECL(stg_ap_stk_v32);
+RTS_FUN_DECL(stg_ap_stk_v64);
+RTS_FUN_DECL(stg_stk_save_v16);
+RTS_FUN_DECL(stg_stk_save_v32);
+RTS_FUN_DECL(stg_stk_save_v64);
+
 /* standard GC & stack check entry points, all defined in HeapStackCheck.cmm */
 
 RTS_FUN_DECL(stg_gc_noregs);
@@ -454,6 +468,8 @@ RTS_FUN_DECL(stg_newPinnedByteArrayzh);
 RTS_FUN_DECL(stg_newAlignedPinnedByteArrayzh);
 RTS_FUN_DECL(stg_isByteArrayPinnedzh);
 RTS_FUN_DECL(stg_isMutableByteArrayPinnedzh);
+RTS_FUN_DECL(stg_isByteArrayWeaklyPinnedzh);
+RTS_FUN_DECL(stg_isMutableByteArrayWeaklyPinnedzh);
 RTS_FUN_DECL(stg_shrinkMutableByteArrayzh);
 RTS_FUN_DECL(stg_resizzeMutableByteArrayzh);
 RTS_FUN_DECL(stg_shrinkSmallMutableArrayzh);
@@ -590,6 +606,11 @@ RTS_FUN_DECL(stg_traceMarkerzh);
 RTS_FUN_DECL(stg_getThreadAllocationCounterzh);
 RTS_FUN_DECL(stg_setThreadAllocationCounterzh);
 
+RTS_FUN_DECL(stg_castWord64ToDoublezh);
+RTS_FUN_DECL(stg_castDoubleToWord64zh);
+RTS_FUN_DECL(stg_castWord32ToFloatzh);
+RTS_FUN_DECL(stg_castFloatToWord32zh);
+
 /* Other misc stuff */
 // See wiki:commentary/compiler/backends/ppr-c#prototypes
 
@@ -627,6 +648,7 @@ extern StgWord RTS_VAR(stable_name_table);
 
 // Profiling.c
 extern unsigned int RTS_VAR(era);
+extern StgWord RTS_VAR(user_era);
 extern unsigned int RTS_VAR(entering_PAP);
 extern StgWord      CCS_OVERHEAD[];
 extern StgWord      CCS_SYSTEM[];
